@@ -2,6 +2,11 @@
 //! Rusty-interaction is a library that allows you to work with Discord's new [Interactions](https://blog.discord.com/slash-commands-are-here-8db0a385d9e6).
 //! It can expose types and provides helper functions to validate your Interactions.
 //! It can optionally provide a handler that allows you to receive interactions via outgoing webhook.
+//! 
+//! Note that Discord also has [official documentation](https://discord.com/developers/docs/intro).
+//! 
+//! ## Examples
+//! See the [`examples`](https://github.com/hugopilot/rusty-interaction/tree/main/examples`) directory.
 
 #[macro_use]
 mod macros;
@@ -24,6 +29,8 @@ pub mod handler;
 pub use actix;
 #[cfg(feature = "handler")]
 pub use attributes::*;
+#[cfg(feature = "handler")]
+pub use actix_web;
 
 #[cfg(all(test, not(feature = "handler")))]
 compile_error!(
